@@ -82,6 +82,9 @@ const (
 
 	osConfigPollIntervalDefault = 10
 	osConfigMetadataPollTimeout = 60
+
+	// Default Google API domain
+	universeDomainDefault = "googleapis.com"
 )
 
 var (
@@ -125,6 +128,7 @@ type config struct {
 	zypperRepoFilePath      string
 	yumRepoFilePath         string
 	instanceID              string
+	universeDomain          string
 	numericProjectID        int64
 	osConfigPollInterval    int
 	debugEnabled            bool
@@ -192,6 +196,7 @@ func parseBool(s string) bool {
 type metadataJSON struct {
 	Instance instanceJSON
 	Project  projectJSON
+	Universe universeJSON
 }
 
 type instanceJSON struct {
@@ -207,6 +212,10 @@ type projectJSON struct {
 	NumericProjectID int64
 }
 
+type universeJSON struct {
+	UniverseDomain string `json:"universeDomain"`
+}
+
 type attributesJSON struct {
 	PollIntervalOld       *json.Number `json:"os-config-poll-interval"`
 	PollInterval          *json.Number `json:"osconfig-poll-interval"`
@@ -245,6 +254,8 @@ func createConfigFromMetadata(md metadataJSON) *config {
 		instanceZone:     old.instanceZone,
 		instanceName:     old.instanceName,
 		instanceID:       old.instanceID,
+
+		universeDomain: universeDomainDefault,
 	}
 
 	if md.Project.ProjectID != "" {
@@ -263,6 +274,10 @@ func createConfigFromMetadata(md metadataJSON) *config {
 		c.instanceID = md.Instance.ID.String()
 	}
 
+	if md.Universe.UniverseDomain != "" {
+		c.universeDomain = md.Universe.UniverseDomain
+	}
+
 	// Check project first then instance as instance metadata overrides project.
 	switch {
 	case md.Project.Attributes.InventoryEnabled != "":
@@ -389,6 +404,11 @@ func setSVCEndpoint(md metadataJSON, c *config) {
 	parts := strings.Split(c.instanceZone, "/")
 	zone := parts[len(parts)-1]
 	c.svcEndpoint = strings.ReplaceAll(c.svcEndpoint, "{zone}", zone)
+
+	// Change hostname according to the universe domain
+	if c.universeDomain != universeDomainDefault {
+		c.svcEndpoint = strings.ReplaceAll(c.svcEndpoint, universeDomainDefault, c.universeDomain)
+	}
 }
 
 func setTraceGetInventory(md metadataJSON, c *config) {
@@ -800,3 +820,13 @@ func DisableInventoryWrite() bool {
 func FreeOSMemory() bool {
 	return strings.EqualFold(freeOSMemory, "true") || freeOSMemory == "1"
 }
+
+// DisableCloudLogging returns true if universe domain is not equal to GDU domain.
+func DisableCloudLogging() bool {
+	return !strings.EqualFold(getAgentConfig().universeDomain, universeDomainDefault)
+}
+
+// UniverseDomain is the cloud universe domain
+func UniverseDomain() string {
+	return getAgentConfig().universeDomain
+}
