@@ -31,7 +31,7 @@ const (
 
 // ReportInventory writes inventory to guest attributes and reports it to agent endpoint.
 func (c *Client) ReportInventory(ctx context.Context) {
-	state := inventory.Get(ctx)
+	state := c.inventoryProvider.Get(ctx)
 
 	if agentconfig.GuestAttributesEnabled() && !agentconfig.DisableInventoryWrite() {
 		clog.Infof(ctx, "Writing inventory to guest attributes")
