@@ -17,7 +17,7 @@ package policies
 import (
 	"github.com/GoogleCloudPlatform/osconfig/packages"
 
-	agentendpointpb "google.golang.org/genproto/googleapis/cloud/osconfig/agentendpoint/v1beta"
+	"cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb"
 )
 
 // changes represents the delta between the actual and the desired package installation state.
