@@ -46,6 +46,8 @@ var extensionMap = map[agentendpointpb.SoftwareRecipe_Step_RunScript_Interpreter
 	agentendpointpb.SoftwareRecipe_Step_RunScript_POWERSHELL:              ".ps1",
 }
 
+var chown = chownFunc
+
 func stepCopyFile(step *agentendpointpb.SoftwareRecipe_Step_CopyFile, artifacts map[string]string, runEnvs []string, stepDir string) error {
 	dest, err := util.NormPath(step.Destination)
 	if err != nil {
@@ -127,6 +129,55 @@ func zipIsDir(name string) bool {
 	return strings.HasSuffix(name, "/")
 }
 
+func ensureSymlinkBelongsToDir(dirPath string, symlink string) error {
+	dirAbs, err := filepath.Abs(dirPath)
+	if err != nil {
+		return err
+	}
+	symlinkAbs, err := filepath.Abs(symlink)
+	if err != nil {
+		return err
+	}
+
+	evaluatedSymlinkAbs, err := filepath.EvalSymlinks(symlinkAbs)
+	if err != nil {
+		return err
+	}
+
+	rel, err := filepath.Rel(dirAbs, evaluatedSymlinkAbs)
+	if err != nil {
+		return err
+	}
+
+	if strings.HasPrefix(rel, "..") {
+		return fmt.Errorf("symlink %s, does not belongs to dir %s, rel %s", symlink, dirPath, rel)
+	}
+
+	return nil
+}
+
+func ensureFilePathBelongsToDir(dirPath string, filePath string) error {
+	dirAbs, err := filepath.Abs(dirPath)
+	if err != nil {
+		return err
+	}
+	fileAbs, err := filepath.Abs(filePath)
+	if err != nil {
+		return err
+	}
+
+	rel, err := filepath.Rel(dirAbs, fileAbs)
+	if err != nil {
+		return err
+	}
+
+	if strings.HasPrefix(rel, "..") {
+		return fmt.Errorf("path %s, does not belongs to dir %s, rel %s", filePath, dirPath, rel)
+	}
+
+	return nil
+}
+
 func extractZip(zipPath string, dst string) error {
 	zr, err := zip.OpenReader(zipPath)
 	if err != nil {
@@ -134,12 +185,17 @@ func extractZip(zipPath string, dst string) error {
 	}
 	defer zr.Close()
 
-	// Check for conflicts
+	// Check that we can extract zip
 	for _, f := range zr.File {
 		filen, err := util.NormPath(filepath.Join(dst, f.Name))
 		if err != nil {
 			return err
 		}
+
+		if err := ensureFilePathBelongsToDir(dst, filen); err != nil {
+			return fmt.Errorf("unable to extract zip archive %s: %w", zipPath, err)
+		}
+
 		stat, err := os.Stat(filen)
 		if os.IsNotExist(err) {
 			continue
@@ -151,7 +207,7 @@ func extractZip(zipPath string, dst string) error {
 			// it's ok if directories already exist
 			continue
 		}
-		return fmt.Errorf("file exists: %s", filen)
+		return fmt.Errorf("unable to extract zip archive %s: file %s is already exists", zipPath, filen)
 	}
 
 	// Create files.
@@ -240,6 +296,11 @@ func checkForConflicts(tr *tar.Reader, dst string) error {
 		if err != nil {
 			return err
 		}
+
+		if err := ensureFilePathBelongsToDir(dst, filen); err != nil {
+			return err
+		}
+
 		stat, err := os.Stat(filen)
 		if os.IsNotExist(err) {
 			continue
@@ -270,7 +331,7 @@ func extractTar(ctx context.Context, tarName string, dst string, archiveType age
 	tr := tar.NewReader(decompressed)
 
 	if err := checkForConflicts(tr, dst); err != nil {
-		return err
+		return fmt.Errorf("unable to extract tar archive %s: %s", tarName, err)
 	}
 
 	file.Seek(0, 0)
@@ -293,6 +354,11 @@ func extractTar(ctx context.Context, tarName string, dst string, archiveType age
 		if err != nil {
 			return err
 		}
+
+		if err := ensureFilePathBelongsToDir(dst, filen); err != nil {
+			return err
+		}
+
 		filedir := filepath.Dir(filen)
 
 		if err := os.MkdirAll(filedir, 0700); err != nil {
@@ -324,11 +390,23 @@ func extractTar(ctx context.Context, tarName string, dst string, archiveType age
 				return err
 			}
 		case tar.TypeLink:
+			if err := ensureSymlinkBelongsToDir(dst, header.Linkname); err != nil {
+				clog.Infof(ctx,
+					"link %s resolved outside of destination %s, for the security reason it is not allowed", header.Linkname, dst)
+				continue
+			}
+
 			if err := os.Link(header.Linkname, filen); err != nil {
 				return err
 			}
 			continue
 		case tar.TypeSymlink:
+			if err := ensureSymlinkBelongsToDir(dst, header.Linkname); err != nil {
+				clog.Infof(ctx,
+					"symlink %s resolved outside of destination %s, for the security reason it is not allowed", header.Linkname, dst)
+				continue
+			}
+
 			if err := os.Symlink(header.Linkname, filen); err != nil {
 				return err
 			}
@@ -506,7 +584,7 @@ func executeCommand(ctx context.Context, cmd string, args []string, workDir stri
 	return err
 }
 
-func chown(file string, uid, gid int) error {
+func chownFunc(file string, uid, gid int) error {
 	// os.Chown unsupported on windows
 	if runtime.GOOS == "windows" {
 		return nil
